@@ -1,11 +1,9 @@
 use strict;
 use warnings;
 package Pod::Weaver::PluginBundle::Author::GETTY;
-BEGIN {
-  $Pod::Weaver::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: GETTY's default Pod::Weaver config
-$Pod::Weaver::PluginBundle::Author::GETTY::VERSION = '0.110';
+$Pod::Weaver::PluginBundle::Author::GETTY::VERSION = '0.111';
 
 use Pod::Weaver::Config::Assembler;
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
@@ -58,7 +56,7 @@ Pod::Weaver::PluginBundle::Author::GETTY - GETTY's default Pod::Weaver config
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 DESCRIPTION
 
